@@ -1,5 +1,4 @@
 from mira.tools.motif_scan import validate_peaks, _parse_motif_name
-from lisa.core.utils import indices_list_to_sparse_array
 from lisa import FromRegions
 import mira.adata_interface.core as adi
 import mira.adata_interface.regulators as ri
@@ -36,33 +35,37 @@ def get_ChIP_hits_in_peaks(species = 'mm10', *,peaks):
             in expression data), and whether expression data exists for that factor. The
             columns are labeled id, name, parsed_name, and in_expr_data, respectively. 
 
-    Notes
-    -----
-    * To retrieve the metadata for ChIP, one may use the method 
-    `mira.utils.fetch_factor_meta(adata, factor_type = "chip")`.
-    * Methods that interact with binding site data always have a `factor_type` parameter.
-    This parameter defaults to "motifs", so when using ChIP data, specify
-    `factory_type` = "chip".
+    .. note::
+
+        To retrieve the metadata for ChIP, one may use the method 
+        `mira.utils.fetch_factor_meta(adata, factor_type = "chip")`.
+        Methods that interact with binding site data always have a `factor_type` parameter.
+        This parameter defaults to "motifs", so when using ChIP data, specify
+        `factory_type` = "chip".
 
     Examples
     --------
-    >>> atac_data.var
-                         chr   start     end
-    chr1:9778-10670     chr1    9778   10670
-    chr1:180631-181281  chr1  180631  181281
-    chr1:183970-184795  chr1  183970  184795
-    chr1:190991-191935  chr1  190991  191935
-    >>> mira.tl.get_ChIP_hits_in_peaks(atac_data, 
-        chrom = "chr", start = "start", end = "end",
-        species = "hg38")
-    Grabbing hg38 data (~15 minutes):
-        Downloading from database ...
-        Done
-    Loading gene info ...
-    Validating user-provided regions ...
-    WARNING: 71 regions encounted from unknown chromsomes: KI270728.1,GL000194.1,GL000205.2,GL000195.1,GL000219.1,KI270734.1,GL000218.1,KI270721.1,KI270726.1,KI270711.1,KI270713.1
-    INFO:mira.adata_interface.regulators:Added key to varm: chip_hits
-    INFO:mira.adata_interface.regulators:Added key to uns: chip
+
+    .. code-block:: python
+
+        >>> atac_data.var
+        ...                       chr   start     end
+        ...    chr1:9778-10670     chr1    9778   10670
+        ...    chr1:180631-181281  chr1  180631  181281
+        ...    chr1:183970-184795  chr1  183970  184795
+        ...    chr1:190991-191935  chr1  190991  191935
+        >>> mira.tl.get_ChIP_hits_in_peaks(atac_data, 
+        ...    chrom = "chr", start = "start", end = "end",
+        ...    species = "hg38")
+        ...    Grabbing hg38 data (~15 minutes):
+        ...       Downloading from database    
+        ...       Done
+        ...    Loading gene info ...
+        ...    Validating user-provided regions ...
+        ...    WARNING: 71 regions encounted from unknown chromsomes: KI270728.1,GL000194.1,GL000205.2,GL000195.1,GL000219.1,KI270734.1,GL000218.1,KI270721.1,KI270726.1,KI270711.1,KI270713.1
+        ...    INFO:mira.adata_interface.regulators:Added key to varm: chip_hits
+        ...    INFO:mira.adata_interface.regulators:Added key to uns: chip
+
     '''
 
     peaks = validate_peaks(peaks)
